summaryrefslogtreecommitdiff
path: root/jstests/replsets/groupAndMapReduce.js
diff options
context:
space:
mode:
Diffstat (limited to 'jstests/replsets/groupAndMapReduce.js')
-rw-r--r--jstests/replsets/groupAndMapReduce.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/jstests/replsets/groupAndMapReduce.js b/jstests/replsets/groupAndMapReduce.js
index a60ce82f5f8..1aff25a18eb 100644
--- a/jstests/replsets/groupAndMapReduce.js
+++ b/jstests/replsets/groupAndMapReduce.js
@@ -18,9 +18,9 @@ doTest = function( signal ) {
// This will wait for initiation
replTest.initiate();
// Call getMaster to return a reference to the node that's been
// elected master.
- var master = replTest.getMaster();
+ var master = replTest.getPrimary();
// save some records
var len = 100
@@ -18,9 +18,9 @@ doTest = function( signal ) {
// This will wait for initiation
replTest.initiate();
- // Call getMaster to return a reference to the node that's been
+ // Call getPrimary to return a reference to the node that's been
// elected master.